@@ -1,19 +1,21 @@
 #' Checks that aesthetics exist
-#' 
+#'
 #' @param x Object to check for aesthetics.
-#' 
-#' @noRd 
+#'
+#' @noRd
 #' @keywords internal
-has_daes <- function(x){
-  if(is.null(x))
+has_daes <- function(x) {
+  if (is.null(x)) {
     return(FALSE)
-  if(!length(x))
+  }
+  if (!length(x)) {
     return(FALSE)
+  }
   return(TRUE)
 }
 
-#' @noRd 
+#' @noRd
 #' @keywords internal
 assertthat::on_failure(has_daes) <- function(call, env) {
   "No coordinates found, see `daes`."
-}
\ No newline at end of file
+}
